import re

from django.contrib.auth.models import AbstractUser
from django.core import validators
from django.db import models

from emissions.models import Emission, Episode, NewsItem, NewsCategory, SoundFile

class User(AbstractUser):
    emissions = models.ManyToManyField(Emission, null=True, blank=True)
    news_categories = models.ManyToManyField(NewsCategory, null=True, blank=True)

    def can_manage(self, object):
        if self.is_staff:
            return True
        if isinstance(object, Emission):
            return object in self.emissions.all()
        if isinstance(object, Episode):
            return object.emission in self.emissions.all()
        if isinstance(object, SoundFile):
            return object.episode.emission in self.emissions.all()
        if isinstance(object, NewsItem):
            return object.emission in self.emissions.all()
        return False
